@@ -1256,12 +1256,12 @@ def _start(client, bot):
 		if not message.author.bot:
 			if str(message.content).startswith(bot._client.user.mention):
 				if bot._help:
-					await message.channel.send(embed=discord.Embed(title="Комманды("+str(len(bot._cmds)-1)+")",description=f"```py\n"+"\n".join(bot._cmds)+"\n```"))
+					await message.channel.send(embed=discord.Embed(title="Комманды("+str(len(bot._cmds))+")",description=f"```py\n"+"\n".join(bot._cmds)+"\n```"))
 			def remember(text):
 				bot._nowcmd=text
 				return True
-			if any([message.content[:len(max(bot._cmds, key=len))].startswith(get_vars(bot._codes["command"][cmd]["prefix"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})+get_vars(bot._codes["command"][cmd]["name"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})) and remember(cmd) for cmd in bot._codes["command"]]):
-				await use(message, bot._nowcmd, get_vars(bot._codes["command"][bot._nowcmd]["prefix"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})+get_vars(bot._codes["command"][bot._nowcmd]["name"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {}), "command")
+			if any([message.content[:len(max(bot._cmds, key=len))].startswith(bot._codes["command"][cmd]["prefix"]+bot._codes["command"][cmd]["name"]) and remember(cmd) for cmd in bot._codes["command"]]):
+				await use(message, bot._nowcmd, bot._codes["command"][bot._nowcmd]["prefix"]+bot._codes["command"][bot._nowcmd]["name"], "command")
 	if bot._self:
 		client.run(bot._token, bot=False)
 	else:
